==============
Working groups
==============

Definition
==========

Technical Committee working groups are entities that get some delegation
of rights (and duties) from the Technical Committee itself. This document
lists them and their current membership.


Current list of working groups
==============================

**Election working group**
  The election working group is tasked with organizing PTL and TC elections,
  following the rules described in the :doc:`charter`.
  It may select election officials for each election, making sure that
  election candidates are not an election official. It should at least have
  3 members. The current members of the election working group are Kendall
  Nelson (diablo_rojo), Jeremy Stanley (fungi), and Tony Breeds (tonyb).


Process for addition or removal
===============================

Proposed modifications to this document require a formal vote from the
Technical Committee membership.
